@@ -5,7 +5,9 @@ package Alt::Data::Frame::ButMore;
 use strict;
 use warnings;
 
-our $VERSION = '0.004_004'; # TRIAL VERSION
+our $VERSION = '0.004_005'; # TRIAL VERSION
+
+1;
 
 __END__
 
@@ -19,7 +21,7 @@ Alt::Data::Frame::ButMore - Alternative implementation of Data::Frame with more
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
 
 =head1 STATUS
 
@@ -209,7 +211,7 @@ If a given argument is non-indexer, it would coerce it by C<indexer_s()>.
 
 =head2 set
 
-    set(Indexer $col_name, Piddle0Dor1D $data)
+    set(Indexer $col_name, ColumnLike $data)
 
 Sets data to column. If C<$col_name> does not exist, it would add a new column.
 
@@ -291,7 +293,7 @@ C<$data>.
     # below types would be coerced to Indexer
     select_rows( Array @which )
     select_rows( ArrayRef $which )
-    select_rows( Piddle0Dor1D $which )
+    select_rows( Piddle $which )
 
 The argument C<$indexer> is an "Indexer", as defined in L<Data::Frame::Types>.
 C<select_rows> returns a new C<Data::Frame> that contains rows that match
@@ -405,7 +407,7 @@ Here are some examples,
 
 =head2 split
 
-    split(Piddle1D $factor)
+    split(ColumnLike $factor)
 
 Splits the data in into groups defined by C<$factor>.
 In a scalar context it returns a hashref mapping value to data frame.
@@ -508,7 +510,7 @@ L<PDL::Primitive/whichND>.
 
 =head2 SERIALIZATION
 
-See L<Data::Frame::Partial::CSV>
+See L<Data::Frame::IO::CSV>
 
 =head2 SYNTAX SUGAR
 
