@@ -33,7 +33,7 @@ use Sereal::Encoder;
 use Text::Table::Tiny;
 use Type::Params;
 use Types::Standard qw(Any ArrayRef CodeRef CycleTuple HashRef Maybe Str);
-use Types::PDL qw(Piddle);
+use Types::PDL qw(Piddle Piddle1D);
 
 use Data::Frame::Column::Helper;
 
@@ -138,7 +138,7 @@ has _row_names => ( is => 'rw', predicate => 1 );
 
 with qw(
   Data::Frame::Role::Rlike
-  Data::Frame::Partial::CSV
+  Data::Frame::IO::CSV
   Data::Frame::Partial::Eval
   Data::Frame::Partial::Sugar
 );
@@ -331,7 +331,7 @@ method rename ((HashRef | CodeRef) $href_or_coderef) {
 method set ($indexer, $data) {
     state $check =
       Type::Params::compile( Indexer->plus_coercions(IndexerFromLabels),
-        Piddle0Dor1D->plus_coercions( ArrayRef, sub { PDL::SV->new($_) } ) );
+        ColumnLike->plus_coercions( ArrayRef, sub { PDL::SV->new($_) } ) );
     ($indexer) = $check->( $indexer, $data );
 
     if ( $data->length == 1 ) {
@@ -634,7 +634,7 @@ method transform ($func) {
 }
 
 
-method split (Piddle0Dor1D $factor) {
+method split (ColumnLike $factor) {
     if ($factor->$_DOES('PDL::Factor')) {
         $factor = $factor->{PDL};
     }
@@ -1006,7 +1006,7 @@ Data::Frame - data frame implementation
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
 
 =head1 STATUS
 
@@ -1196,7 +1196,7 @@ If a given argument is non-indexer, it would coerce it by C<indexer_s()>.
 
 =head2 set
 
-    set(Indexer $col_name, Piddle0Dor1D $data)
+    set(Indexer $col_name, ColumnLike $data)
 
 Sets data to column. If C<$col_name> does not exist, it would add a new column.
 
@@ -1278,7 +1278,7 @@ C<$data>.
     # below types would be coerced to Indexer
     select_rows( Array @which )
     select_rows( ArrayRef $which )
-    select_rows( Piddle0Dor1D $which )
+    select_rows( Piddle $which )
 
 The argument C<$indexer> is an "Indexer", as defined in L<Data::Frame::Types>.
 C<select_rows> returns a new C<Data::Frame> that contains rows that match
@@ -1392,7 +1392,7 @@ Here are some examples,
 
 =head2 split
 
-    split(Piddle1D $factor)
+    split(ColumnLike $factor)
 
 Splits the data in into groups defined by C<$factor>.
 In a scalar context it returns a hashref mapping value to data frame.
@@ -1495,7 +1495,7 @@ L<PDL::Primitive/whichND>.
 
 =head2 SERIALIZATION
 
-See L<Data::Frame::Partial::CSV>
+See L<Data::Frame::IO::CSV>
 
 =head2 SYNTAX SUGAR
 
