@@ -40,12 +40,11 @@ my %data_setup = (
             return $df;
         }
     },
-    economics => { params => { col_types => { date => 'PDL::DateTime' } } },
-    economics_long =>
-      { params => { col_types => { date => 'PDL::DateTime' } } },
-    mpg       => {},
-    mtcars    => {},
-    txhousing => {},
+    economics      => { params => { dtype => { date => 'datetime' } } },
+    economics_long => { params => { dtype => { date => 'datetime' } } },
+    mpg            => {},
+    mtcars         => {},
+    txhousing      => {},
 );
 my @data_names = sort keys %data_setup;
 
@@ -107,7 +106,7 @@ Data::Frame::Examples - Example data sets
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
 
 =head1 SYNOPSIS
 
