@@ -16,7 +16,7 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 
 my $NumericIndices =
-  Piddle0Dor1D->where( sub { $_->type ne 'byte' and not is_discrete($_) } );
+  ColumnLike->where( sub { $_->type ne 'byte' and not is_discrete($_) } );
 
 fun _as_indexer ($fallback_indexer_class) {
     return sub {
@@ -52,7 +52,7 @@ Data::Frame::Indexer - Function interface for indexer
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
 
 =head1 DESCRIPTION
 
