@@ -5,13 +5,13 @@ package Data::Frame::Indexer::Role;
 use Data::Frame::Role;
 
 use Types::Standard qw(ArrayRef);
-use Data::Frame::Types qw(Piddle0Dor1D);
+use Data::Frame::Types qw(ColumnLike);
 
 
 has indexer => (
     is  => 'ro',
     isa => (
-        ArrayRef->plus_coercions( Piddle0Dor1D,
+        ArrayRef->plus_coercions( ColumnLike,
             sub { ( $_->badflag ? $_->where( $_->isgood ) : $_ )->unpdl }
         )
     ),
@@ -33,7 +33,7 @@ Data::Frame::Indexer::Role - Role for Data::Frame indexer
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
 
 =head1 ATTRIBUTES
 
