@@ -8,7 +8,8 @@ use warnings;
 use Type::Library -base, -declare => qw(
   DataFrame
   Indexer
-  Piddle0Dor1D
+  DataType
+  Column ColumnLike
   IndexerFromLabels IndexerFromIndices
 );
 
@@ -20,7 +21,15 @@ declare DataFrame, as ConsumerOf ["Data::Frame"];
 
 declare Indexer, as ConsumerOf ["Data::Frame::Indexer::Role"];
 
-declare Piddle0Dor1D, as Piddle [ ndims_min => 0, ndims_max => 1 ];
+declare ColumnLike, as ConsumerOf['PDL'], where { $_->ndims <= 1 };
+declare Column, as ColumnLike;
+
+declare DataType, as Enum [
+    qw(
+      ushort long indx longlong float double
+      string factor logical datetime
+      )
+];
 
 declare_coercion "IndexerFromLabels", to_type Indexer, from Any, via {
     require Data::Frame::Indexer;
@@ -45,7 +54,7 @@ Data::Frame::Types - Custom Type::Tiny types
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
 
 =head1 DESCRIPTION 
 
@@ -56,13 +65,26 @@ Types:
 =for :list
 * DataFrame
 * Indexer
-* Piddle0Dor1D
+* ColumnLike
+This is basically piddle of 0D and 1D.
+* Column
+Now it's same as ColumnLike, but will likely evolve into a dedicated type
+in future.
+* DataType
+One of the PDL types
+C<"ushort">, C<"long">, C<"indx">, C<"longlong">, C<"float">, C<"double">,
+or C<"string"> (PDL::SV), C<"factor"> (PDL::Factor),
+C<"logical"> (PDL::Logical), C<"datetime"> (PDL::DateTime).
 
 Coercions:
 =for :list
 * IndexerFromLabels
 * IndexerFromIndices
 
+=head1 SEE ALSO
+
+L<Data::Frame>
+
 =head1 AUTHORS
 
 =over 4
