@@ -1,5 +1,7 @@
 package PDL::Logical;
 
+# ABSTRACT: PDL subclass for keeping logical data
+
 use 5.016;
 use warnings;
 
@@ -56,11 +58,11 @@ __END__
 
 =head1 NAME
 
-PDL::Logical
+PDL::Logical - PDL subclass for keeping logical data
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
 
 =head1 SYNOPSIS
 
