@@ -1,5 +1,7 @@
 package PDL::SV;
 
+# ABSTRACT: PDL subclass for keeping scalar data (like strings)
+
 use 5.016;
 use warnings;
 
@@ -8,6 +10,8 @@ use PDL::Primitive qw(which whichND);
 use Data::Rmap qw(rmap_array);
 use Safe::Isa;
 use Storable qw(dclone);
+use Type::Params;
+use Types::Standard qw(slurpy ArrayRef ConsumerOf Int);
 use List::AllUtils ();
 
 use parent 'PDL';
@@ -135,17 +139,23 @@ around qw(slice dice) => sub : lvalue {
 
 
 sub glue {
-    my ($self, $dim, @piddles) = @_;
+    my $self = shift;
+
+    state $check =
+      Type::Params::compile( Int,
+        slurpy ArrayRef [ ConsumerOf ['PDL::SV'] ] );
+    my ( $dim, $others ) = $check->(@_);
+
     my $class = ref($self);
 
     if ($dim != 0) {
         die('PDL::SV::glue does not yet support $dim != 0');
     }
 
-    my $data = [ map { @{$_->unpdl} } ($self, @piddles) ];
+    my $data = [ map { @{$_->unpdl} } ($self, @$others) ];
     my $new = $class->new($data);
-    if (List::AllUtils::any { $_->badflag } ($self, @piddles)) {
-        my $isbad = pdl([ map { @{$_->isbad->unpdl} } ($self, @piddles) ]);
+    if (List::AllUtils::any { $_->badflag } ($self, @$others)) {
+        my $isbad = pdl([ map { @{$_->isbad->unpdl} } ($self, @$others) ]);
         $new->{PDL} = $new->{PDL}->setbadif($isbad);
     }
     return $new;
@@ -365,11 +375,17 @@ __END__
 
 =head1 NAME
 
-PDL::SV
+PDL::SV - PDL subclass for keeping scalar data (like strings)
 
 =head1 VERSION
 
-version 0.004_004
+version 0.004_005
+
+=head1 SYNOPSIS
+
+    use PDL::SV ();
+    
+    my $p = PDL::SV->new( [ qw(foo bar) ] );
 
 =head1 METHODS
 
@@ -391,6 +407,10 @@ Cannot be run inplace.
 Match against a plain a regular expression.
 Returns a piddle of the same dimension.
 
+=head1 SEE ALSO
+
+L<PDL>
+
 =head1 AUTHORS
 
 =over 4
